xapres_package
==============================
[![Build Status](https://github.com/jkingslake/xapres_package/workflows/Tests/badge.svg)](https://github.com/jkingslake/xapres_package/actions)
[![codecov](https://codecov.io/gh/jkingslake/xapres_package/branch/main/graph/badge.svg)](https://codecov.io/gh/jkingslake/xapres_package)
[![License:MIT](https://img.shields.io/badge/License-MIT-lightgray.svg?style=flt-square)](https://opensource.org/licenses/MIT)[![pypi](https://img.shields.io/pypi/v/xapres_package.svg)](https://pypi.org/project/xapres_package)
<!-- [![conda-forge](https://img.shields.io/conda/dn/conda-forge/xapres_package?label=conda-forge)](https://anaconda.org/conda-forge/xapres_package) -->[![Documentation Status](https://readthedocs.org/projects/xapres_package/badge/?version=latest)](https://xapres_package.readthedocs.io/en/latest/?badge=latest)


Code for processin

--------

<p><small>Project based on the <a target="_blank" href="https://github.com/jbusecke/cookiecutter-science-project">cookiecutter science project template</a>.</small></p>
